@@ -48,20 +48,21 @@ if (!isGeneric("se.coef")) {
 
 
 
-if (!isGeneric("mcsamp")) {
-    setGeneric("mcsamp",
-               function(object, ...)
-               standardGeneric("mcsamp"))
-}
+#if (!isGeneric("mcsamp")) {
+#    setGeneric("mcsamp",
+#               function(object, ...)
+#               standardGeneric("mcsamp"))
+#}
 
 
 
 
-if (!isGeneric("terms.bayes")) {
-    setGeneric("terms.bayes",
-               function(x, ...)
-               standardGeneric("terms.bayes"))
-}
+#if (!isGeneric("terms.bayes")) {
+#    setGeneric("terms.bayes",
+#               function(x, ...)
+#               standardGeneric("terms.bayes"))
+#}
+
 
 if (!isGeneric("tracplot")) {
     setGeneric("traceplot",
